<!DOCTYPE TS><TS>
<context>
    <name></name>
    <message>
        <source>Error in config.py:</source>
        <translation type="unfinished">Erro em config.py:</translation>
    </message>
    <message>
        <source>Error when running plugin:</source>
        <translation type="unfinished">Erro ao executar plugin:</translation>
    </message>
    <message>
        <source>Unable to load file.</source>
        <translation type="unfinished">Não foi possível abrir o arquivo.</translation>
    </message>
    <message>
        <source>Invalid file format.</source>
        <translation type="unfinished">Formato de arquivo inválido.</translation>
    </message>
    <message>
        <source>Unable to save file.</source>
        <translation type="unfinished">Não foi possível salvar o arquivo.</translation>
    </message>
    <message>
        <source>Unable to parse XML:</source>
        <translation type="unfinished">Não foi possível converter o XML:</translation>
    </message>
    <message>
        <source>Unrecognised encoding.</source>
        <translation type="unfinished">Codificação desconhecida.</translation>
    </message>
    <message>
        <source>Missing answer on line:</source>
        <translation type="unfinished">Falta resposta na linha:</translation>
    </message>
    <message>
        <source>Unable to load database.
Creating tmp file.</source>
        <translation type="unfinished">Não foi possível carregar a base de dados.
Criando arquivo temporário.</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation type="unfinished">Mnemosyne</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>File exists:</source>
        <translation type="unfinished">Arquivo já existe:</translation>
    </message>
    <message>
        <source>&amp;Overwrite</source>
        <translation type="unfinished">&amp;Sobrescrever</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Cancelar</translation>
    </message>
    <message>
        <source>Removed duplicates: </source>
        <translation type="unfinished">Remover duplicatas: </translation>
    </message>
    <message>
        <source>There are cards with different answers for question:

</source>
        <translation type="unfinished">Existem cartões com diferentes respostas para a questão:</translation>
    </message>
    <message>
        <source>&amp;Merge and edit</source>
        <translation type="unfinished">&amp;Mesclar e editar</translation>
    </message>
    <message>
        <source>&amp;Don&apos;t merge</source>
        <translation type="unfinished">&amp;Não mesclar</translation>
    </message>
    <message>
        <source>Done!</source>
        <translation type="unfinished">Pronto!</translation>
    </message>
    <message>
        <source>You don&apos;t remember this card yet.</source>
        <translation type="unfinished">Você ainda não memorizou este cartão.</translation>
    </message>
    <message>
        <source>Like &apos;0&apos;, but it&apos;s getting more familiar.</source>
        <translation type="unfinished">Como &apos;0&apos;, mas está se familiarizando.</translation>
    </message>
    <message>
        <source> Show it less often.</source>
        <translation type="unfinished">Mostrar com menor freqüência.</translation>
    </message>
    <message>
        <source>You&apos;ve memorised this card now,</source>
        <translation type="unfinished">Você memorizou este cartão,</translation>
    </message>
    <message>
        <source> and will probably remember it for a few days.</source>
        <translation type="unfinished"> e provavelmente irá lembrá-lo por alguns dias.</translation>
    </message>
    <message>
        <source>You have forgotten this card completely.</source>
        <translation type="unfinished">Você esqueceu este cartão.</translation>
    </message>
    <message>
        <source>Barely correct answer. The interval was way too long.</source>
        <translation type="unfinished">Resposta correta com dificuldade. O intervalo foi muito longo.</translation>
    </message>
    <message>
        <source>Correct answer, but with much effort.</source>
        <translation type="unfinished">Resposta correta, mas com muito esforço.</translation>
    </message>
    <message>
        <source> The interval was probably too long.</source>
        <translation type="unfinished"> O intervalo provavelmente foi muito longo.</translation>
    </message>
    <message>
        <source>Correct answer, with some effort.</source>
        <translation type="unfinished">Resposta correta, com algum esforço.</translation>
    </message>
    <message>
        <source> The interval was probably just right.</source>
        <translation type="unfinished">O intervalo provavelmente foi correto.</translation>
    </message>
    <message>
        <source>Correct answer, but without any</source>
        <translation type="unfinished">Resposta correta, mas sem nenhuma dificuldade.</translation>
    </message>
    <message>
        <source> difficulties. The interval was probably too short.</source>
        <translation type="unfinished">O intervalo provavelmente foi muito curto.</translation>
    </message>
</context>
<context>
    <name>AboutDlg</name>
    <message>
        <source>Mnemosyne</source>
        <translation type="unfinished">Mnemosyne</translation>
    </message>
    <message>
        <source>Main author: Peter Bienstman

</source>
        <translation type="unfinished">Autor principal: Peter Bienstman</translation>
    </message>
    <message>
        <source>More info: http://mnemosyne-proj.org
</source>
        <translation type="unfinished">Mais informações: http://mnemosyne-proj.org</translation>
    </message>
</context>
<context>
    <name>AboutFrm</name>
    <message>
        <source>About</source>
        <translation type="unfinished">Sobre</translation>
    </message>
</context>
<context>
    <name>ActivateCategoriesFrm</name>
    <message>
        <source>Activate categories</source>
        <translation type="unfinished">Habilitar categorias</translation>
    </message>
    <message>
        <source>Select the categories to activate:</source>
        <translation type="unfinished">Escolha as categorias que deseja habilitar:</translation>
    </message>
    <message>
        <source>Activate none</source>
        <translation type="unfinished">Não habilitar nenhuma</translation>
    </message>
    <message>
        <source>Activate all</source>
        <translation type="unfinished">Habilitar todas</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="unfinished">Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Cancelar</translation>
    </message>
</context>
<context>
    <name>AddItemsDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation type="unfinished">&lt;padrão&gt;</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation type="unfinished">Mnemosyne</translation>
    </message>
    <message>
        <source>Abandon current card?</source>
        <translation type="unfinished">Abandonar cartão?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation type="unfinished">&amp;Sim</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation type="unfinished">&amp;Não</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation type="unfinished">Questão:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation type="unfinished">Resposta:</translation>
    </message>
    <message>
        <source>Written form:</source>
        <translation type="unfinished">Forma escrita:</translation>
    </message>
    <message>
        <source>Translation:</source>
        <translation type="unfinished">Tradução:</translation>
    </message>
    <message>
        <source>Card is already in database.
</source>
        <translation type="unfinished">Cartão já está na base de dados.</translation>
    </message>
    <message>
        <source>Duplicate not added.</source>
        <translation type="unfinished">Duplicata não adicionada.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>There are different answers for</source>
        <translation type="unfinished">Existem respostas diferentes para</translation>
    </message>
    <message>
        <source> this question:

</source>
        <translation type="unfinished"> esta questão:</translation>
    </message>
    <message>
        <source>&amp;Merge and edit</source>
        <translation type="unfinished">&amp;Mesclar e editar</translation>
    </message>
    <message>
        <source>&amp;Add as is</source>
        <translation type="unfinished">&amp;Adicionar assim mesmo</translation>
    </message>
    <message>
        <source>&amp;Do not add</source>
        <translation type="unfinished">&amp;Não adicionar</translation>
    </message>
</context>
<context>
    <name>AddItemsFrm</name>
    <message>
        <source>Add cards</source>
        <translation type="unfinished">Adicionar cartões</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation type="unfinished">Categoria:</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation type="unfinished">Questão:</translation>
    </message>
    <message>
        <source>Pronunciation:</source>
        <translation type="unfinished">Pronúncia:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation type="unfinished">Resposta:</translation>
    </message>
    <message>
        <source>Add &amp;vice versa too</source>
        <translation type="unfinished">Adicionar &amp;vice versa também</translation>
    </message>
    <message>
        <source>Alt+V</source>
        <translation type="unfinished">Alt+V</translation>
    </message>
    <message>
        <source>Select initial grade:</source>
        <translation type="unfinished">Escolha o nível inicial:</translation>
    </message>
    <message>
        <source>&amp;0</source>
        <translation type="unfinished">&amp;0</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation type="unfinished">Ctrl+0</translation>
    </message>
    <message>
        <source>You don&apos;t remember this item yet or forgot it.</source>
        <translation type="unfinished">Você ainda não memorizou este cartão ou o esqueceu.</translation>
    </message>
    <message>
        <source>&amp;1</source>
        <translation type="unfinished">&amp;1</translation>
    </message>
    <message>
        <source>Ctrl+1</source>
        <translation type="unfinished">Ctrl+1</translation>
    </message>
    <message>
        <source>Like &apos;0&apos;, but the item is getting more familiar.</source>
        <translation type="unfinished">Como o &apos;0&apos;, mas está se familiarizando com o item.</translation>
    </message>
    <message>
        <source>&amp;2</source>
        <translation type="unfinished">&amp;2</translation>
    </message>
    <message>
        <source>Ctrl+2</source>
        <translation type="unfinished">Ctrl+2</translation>
    </message>
    <message>
        <source>You&apos;ve memorised this item now, and will probably remember it for a few days.</source>
        <translation type="unfinished">Você memorizou este item, e provavelmente irá lembrar-se dele por alguns dias.</translation>
    </message>
    <message>
        <source>&amp;3</source>
        <translation type="unfinished">&amp;3</translation>
    </message>
    <message>
        <source>Ctrl+3</source>
        <translation type="unfinished">Ctrl+3</translation>
    </message>
    <message>
        <source>Correct answer, but with much effort. The interval was probably too long</source>
        <translation type="unfinished">Resposta correta, mas com muito esforço. O intervalo provavelmente foi muito longo.</translation>
    </message>
    <message>
        <source>&amp;4</source>
        <translation type="unfinished">&amp;4</translation>
    </message>
    <message>
        <source>Ctrl+4</source>
        <translation type="unfinished">Ctrl+4</translation>
    </message>
    <message>
        <source>Correct answer, with some effort. The interval was probably just right.</source>
        <translation type="unfinished">Resposta correta, com algum esforço. O intervalo provavelmente foi correto.</translation>
    </message>
    <message>
        <source>&amp;5</source>
        <translation type="unfinished">&amp;5</translation>
    </message>
    <message>
        <source>Ctrl+5</source>
        <translation type="unfinished">Ctrl+5</translation>
    </message>
    <message>
        <source>Correct answer, but without any difficulties. The interval was probably too short.</source>
        <translation type="unfinished">Resposta correta, mas sem nenhuma dificuldade. O intervalo provavelmente foi muito curto.</translation>
    </message>
    <message>
        <source>Type question and answer, then pick initial grade.</source>
        <translation type="unfinished">Digite a questão e a resposta, e escolha o nível inicial.</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation type="obsolete">&amp;Pré visualizar</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation type="unfinished">Ctrl+P</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished">&amp;Sair</translation>
    </message>
    <message>
        <source>Alt+X</source>
        <translation type="unfinished">Alt+X</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChangeCategoryFrm</name>
    <message>
        <source>Change category</source>
        <translation type="unfinished">Mudar categoria</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation type="unfinished">Categoria:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="unfinished">Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Cancelar</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation type="unfinished">Alt+C</translation>
    </message>
</context>
<context>
    <name>ConfigurationFrm</name>
    <message>
        <source>Mnemosyne configuration</source>
        <translation type="unfinished">Configurações do Mnemosyne</translation>
    </message>
    <message>
        <source>Hover with the mouse over the buttons to get extra information.</source>
        <translation type="unfinished">Posicione o mouse sobre as opções para obter informações adicionais.</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation type="unfinished">Aparência</translation>
    </message>
    <message>
        <source>Set Q/A font</source>
        <translation type="unfinished">Fonte das Q/R</translation>
    </message>
    <message>
        <source>Set the font used when showing single questions and answers</source>
        <translation type="unfinished">Escolher a fonte a ser utilizada quando mostrando questões e respostas</translation>
    </message>
    <message>
        <source>Set list font</source>
        <translation type="unfinished">Fonte em listas</translation>
    </message>
    <message>
        <source>Set the font used when showing the list of all the cards in the deck</source>
        <translation type="unfinished">Escolher a fonte a ser utilizada quando mostrando a lista de todos os cartões</translation>
    </message>
    <message>
        <source>Increase size of non-latin characters by</source>
        <translation type="unfinished">Aumentar o tamanho de caracteres não-latinos em</translation>
    </message>
    <message>
        <source>Sometimes complex glyphs are hard to read at the default latin font size</source>
        <translation type="unfinished">Algumas vezes símbolos complexos são difíceis de se ler com o tamanho padrão das fontes latinas</translation>
    </message>
    <message>
        <source>point(s)</source>
        <translation type="unfinished">ponto(s)</translation>
    </message>
    <message>
        <source>Log uploading</source>
        <translation type="unfinished">Envio de utilização</translation>
    </message>
    <message>
        <source>Upload anonymous logs</source>
        <translation type="unfinished">Enviar dados de utilização anonimamente</translation>
    </message>
    <message>
        <source>Share anonymous statistics to contribute to memory research</source>
        <translation type="unfinished">Compartilhar estatísticas anonimamente para contribuir com a pesquisa de memorização</translation>
    </message>
    <message>
        <source>Duplicate handling</source>
        <translation type="unfinished">Tratamento de duplicatas</translation>
    </message>
    <message>
        <source>Check for duplicates when adding new cards</source>
        <translation type="unfinished">Verificar duplicatas ao adicionar novos cartões</translation>
    </message>
    <message>
        <source>Allow duplicates in different categories</source>
        <translation type="unfinished">Permitir duplicatas em categorias diferentes</translation>
    </message>
    <message>
        <source>Repetition process</source>
        <translation type="unfinished">Processo de repetição</translation>
    </message>
    <message>
        <source>Number of grade 0 cards to learn at once:</source>
        <translation type="obsolete">Número de cartões nível 0 para aprender simultaneamente:</translation>
    </message>
    <message>
        <source>Note: this is NOT the number of grade 0 cards you want to memorise *per day*</source>
        <translation type="unfinished">Nota: este NÃO é o número de cartões de nível 0 que você quer memorizar *por dia*</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>Defaults</source>
        <translation type="unfinished">Padrões</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Cancelar</translation>
    </message>
    <message>
        <source>Learn new cards in random order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of grade 0 cards to hold in your hand:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditItemFrm</name>
    <message>
        <source>Edit card</source>
        <translation type="unfinished">Editar cartão</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation type="unfinished">Categoria:</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation type="unfinished">Questão:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation type="unfinished">Resposta:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="unfinished">Alt+O</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation type="unfinished">&amp;Pré visualizar</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation type="unfinished">Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Cancelar</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation type="unfinished">Alt+C</translation>
    </message>
</context>
<context>
    <name>EditItemsDlg</name>
    <message>
        <source>Please wait...</source>
        <translation type="unfinished">Por favor aguarde...</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;Editar</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation type="unfinished">Ctrl+E</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation type="unfinished">&amp;Pré visualizar</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation type="unfinished">Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Add vice versa</source>
        <translation type="unfinished">&amp;Adicionar vice versa</translation>
    </message>
    <message>
        <source>S&amp;tatistics</source>
        <translation type="unfinished">Es&amp;tatísticas</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation type="unfinished">Ctrl+T</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">&amp;Apagar</translation>
    </message>
    <message>
        <source>&amp;Change category</source>
        <translation type="unfinished">&amp;Mudar categoria</translation>
    </message>
    <message>
        <source>Add &amp;vice versa</source>
        <translation type="unfinished">Adicionar &amp;vice versa</translation>
    </message>
    <message>
        <source>Add vice versa of these cards?</source>
        <translation type="unfinished">Adicionar vice versa a estes cartões?</translation>
    </message>
    <message>
        <source>Add vice versa of this card?</source>
        <translation type="unfinished">Adicionar vice versa a este cartão?</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation type="unfinished">Mnemosyne</translation>
    </message>
    <message>
        <source>

This could create duplicates if the vice </source>
        <translation type="unfinished">Isto pode criar duplicatas se os vice </translation>
    </message>
    <message>
        <source>versas are already present, 
so you might want to run </source>
        <translation type="unfinished">versas já existirem, 
então você pode querer executar a </translation>
    </message>
    <message>
        <source>clean duplicates&apos; afterwards.</source>
        <translation type="unfinished">limpeza de duplicatas depois.</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation type="unfinished">&amp;Sim</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation type="unfinished">&amp;Não</translation>
    </message>
    <message>
        <source>Grade:</source>
        <translation type="unfinished">Nível:</translation>
    </message>
    <message>
        <source>Easiness:</source>
        <translation type="unfinished">Facilidade:</translation>
    </message>
    <message>
        <source>Repetitions:</source>
        <translation type="unfinished">Repetições:</translation>
    </message>
    <message>
        <source>Lapses:</source>
        <translation type="unfinished">Passagens:</translation>
    </message>
    <message>
        <source>Days since last repetition:</source>
        <translation type="unfinished">Dias desde a última repetição:</translation>
    </message>
    <message>
        <source>Days until next repetition:</source>
        <translation type="unfinished">Dias até a próxima repetição:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>Delete these cards?</source>
        <translation type="unfinished">Apagar estes cartões?</translation>
    </message>
    <message>
        <source>Delete this card?</source>
        <translation type="unfinished">Apagar este cartão?</translation>
    </message>
    <message>
        <source>The text you entered was not found.</source>
        <translation type="unfinished">O texto digitado não foi encontrado.</translation>
    </message>
    <message>
        <source>&amp;Find again</source>
        <translation type="unfinished">&amp;Procurar novamente</translation>
    </message>
    <message>
        <source>F</source>
        <translation type="unfinished">P</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation type="unfinished">&amp;Procurar</translation>
    </message>
    <message>
        <source>Alt+F</source>
        <translation type="obsolete"></translation>
    </message>
</context>
<context>
    <name>EditItemsFrm</name>
    <message>
        <source>Question</source>
        <translation type="unfinished">Questão</translation>
    </message>
    <message>
        <source>Answer</source>
        <translation type="unfinished">Resposta</translation>
    </message>
    <message>
        <source>Category</source>
        <translation type="unfinished">Categoria</translation>
    </message>
    <message>
        <source>Edit deck</source>
        <translation type="unfinished">Editar cartões</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation type="unfinished">&amp;Procurar</translation>
    </message>
    <message>
        <source>To edit a card, right-click on it.</source>
        <translation type="unfinished">Para editar um cartão, clique com o botão direito sobre ele.</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished">&amp;Sair</translation>
    </message>
    <message>
        <source>Alt+X</source>
        <translation type="unfinished">Alt+X</translation>
    </message>
    <message>
        <source>Alt+F</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>All Files (*);;</source>
        <translation type="unfinished">Todos os arquivos (*);;</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="unfinished">Exportar</translation>
    </message>
</context>
<context>
    <name>ExportFrm</name>
    <message>
        <source>Export to file</source>
        <translation type="unfinished">Exportar para um arquivo</translation>
    </message>
    <message>
        <source>File format:</source>
        <translation type="unfinished">Formato do arquivo:</translation>
    </message>
    <message>
        <source>File to export to:</source>
        <translation type="unfinished">Arquivo para exportação:</translation>
    </message>
    <message>
        <source>&amp;Browse</source>
        <translation type="unfinished">&amp;Navegar</translation>
    </message>
    <message>
        <source>Categories to export:</source>
        <translation type="unfinished">Categorias a exportar:</translation>
    </message>
    <message>
        <source>&amp;Select all</source>
        <translation type="unfinished">&amp;Escolher todas</translation>
    </message>
    <message>
        <source>Reset learning data on export</source>
        <translation type="unfinished">Reiniciar dados de aprendizagem ao exportar</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="unfinished">Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Cancelar</translation>
    </message>
</context>
<context>
    <name>ImportDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation type="unfinished">&lt;padrão&gt;</translation>
    </message>
    <message>
        <source>All Files (*);;</source>
        <translation type="unfinished">Todos os arquivos (*);;</translation>
    </message>
    <message>
        <source>Import</source>
        <translation type="unfinished">Importar</translation>
    </message>
</context>
<context>
    <name>ImportFrm</name>
    <message>
        <source>Import from file</source>
        <translation type="unfinished">Importar do arquivo</translation>
    </message>
    <message>
        <source>File format:</source>
        <translation type="unfinished">Formato do arquivo:</translation>
    </message>
    <message>
        <source>File to import from:</source>
        <translation type="unfinished">Arquivo a importar:</translation>
    </message>
    <message>
        <source>&amp;Browse</source>
        <translation type="unfinished">&amp;Navegar</translation>
    </message>
    <message>
        <source>Put cards without category into this category:</source>
        <translation type="unfinished">Colocar cartões sem categoria nesta categoria:</translation>
    </message>
    <message>
        <source>Note: all cards will be added to the current database.</source>
        <translation type="unfinished">Nota: todos os cartões serão adicionados a base de dados.</translation>
    </message>
    <message>
        <source>Reset learning data on import</source>
        <translation type="unfinished">Reiniciar dados de aprendizagem ao importar</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="unfinished">Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Cancelar</translation>
    </message>
</context>
<context>
    <name>MainDlg</name>
    <message>
        <source>Mnemosyne databases (*.mem)</source>
        <translation type="unfinished">Bases de dados do Mnemosyne (*.mem)</translation>
    </message>
    <message>
        <source>New</source>
        <translation type="unfinished">Nova</translation>
    </message>
    <message>
        <source>Please wait...</source>
        <translation type="unfinished">Por favor aguarde...</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation type="unfinished">Mnemosyne</translation>
    </message>
    <message>
        <source>Delete current card?</source>
        <translation type="unfinished">Apagar cartão atual?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation type="unfinished">&amp;Sim</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation type="unfinished">&amp;Não</translation>
    </message>
    <message>
        <source>Returns in </source>
        <translation type="unfinished">Retornar em </translation>
    </message>
    <message>
        <source> day(s).</source>
        <translation type="unfinished"> dia(s).</translation>
    </message>
    <message>
        <source>Next repetition: today.</source>
        <translation type="unfinished">Próxima repetição: hoje.</translation>
    </message>
    <message>
        <source>Next repetition: tomorrow.</source>
        <translation type="unfinished">Próxima repetição: amanhã.</translation>
    </message>
    <message>
        <source>Next repetition in </source>
        <translation type="unfinished">Próxima repetição em </translation>
    </message>
    <message>
        <source> days.</source>
        <translation type="unfinished"> dia(s).</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation type="unfinished">Questão:</translation>
    </message>
    <message>
        <source>&lt;default&gt;</source>
        <translation type="unfinished">&lt;padrão&gt;</translation>
    </message>
    <message>
        <source>Show &amp;answer</source>
        <translation type="obsolete">Mostrar &amp;resposta</translation>
    </message>
    <message>
        <source>Learn ahead of schedule</source>
        <translation type="unfinished">Estudar além do agendado</translation>
    </message>
    <message>
        <source>Pick days until next repetition:</source>
        <translation type="unfinished">Escolha os dias até a próxima repetição:</translation>
    </message>
    <message>
        <source>Grade your answer:</source>
        <translation type="unfinished">Escolha o nível da sua resposta:</translation>
    </message>
    <message>
        <source>Scheduled: </source>
        <translation type="unfinished">Agendados: </translation>
    </message>
    <message>
        <source>Not memorised: </source>
        <translation type="unfinished">Não memorizados: </translation>
    </message>
    <message>
        <source>All: </source>
        <translation type="unfinished">Todos: </translation>
    </message>
    <message>
        <source>Show answer</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainFrm</name>
    <message>
        <source>Mnemosyne</source>
        <translation type="unfinished">Mnemosyne</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation type="unfinished">Questão:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation type="unfinished">Resposta:</translation>
    </message>
    <message>
        <source>Show answer</source>
        <translation type="unfinished">Mostrar resposta</translation>
    </message>
    <message>
        <source>Grade your answer:</source>
        <translation type="unfinished">Escolha o nível da sua resposta:</translation>
    </message>
    <message>
        <source>&amp;0</source>
        <translation type="unfinished">&amp;0</translation>
    </message>
    <message>
        <source>0</source>
        <translation type="unfinished">0</translation>
    </message>
    <message>
        <source>&amp;1</source>
        <translation type="unfinished">&amp;1</translation>
    </message>
    <message>
        <source>1</source>
        <translation type="unfinished">1</translation>
    </message>
    <message>
        <source>&amp;2</source>
        <translation type="unfinished">&amp;2</translation>
    </message>
    <message>
        <source>2</source>
        <translation type="unfinished">2</translation>
    </message>
    <message>
        <source>&amp;3</source>
        <translation type="unfinished">&amp;3</translation>
    </message>
    <message>
        <source>3</source>
        <translation type="unfinished">3</translation>
    </message>
    <message>
        <source>&amp;4</source>
        <translation type="unfinished">&amp;4</translation>
    </message>
    <message>
        <source>4</source>
        <translation type="unfinished">4</translation>
    </message>
    <message>
        <source>&amp;5</source>
        <translation type="unfinished">&amp;5</translation>
    </message>
    <message>
        <source>5</source>
        <translation type="unfinished">5</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;Novo</translation>
    </message>
    <message>
        <source>.</source>
        <translation type="unfinished">.</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation type="unfinished">Ctrl+N</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation type="unfinished">&amp;Abrir...</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation type="unfinished">Ctrl+O</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation type="unfinished">&amp;Salvar</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation type="unfinished">Ctrl+S</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation type="unfinished">Salvar &amp;Como...</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished">Sai&amp;r</translation>
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished">Sobre</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation type="unfinished">&amp;Sobre</translation>
    </message>
    <message>
        <source>Add cards</source>
        <translation type="unfinished">Adicionar Cartões</translation>
    </message>
    <message>
        <source>&amp;Add cards</source>
        <translation type="unfinished">&amp;Adicionar Cartões</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation type="unfinished">Ctrl+A</translation>
    </message>
    <message>
        <source>Activate cate&amp;gories</source>
        <translation type="unfinished">Ativar &amp;categorias</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation type="unfinished">Ctrl+G</translation>
    </message>
    <message>
        <source>Edit deck</source>
        <translation type="unfinished">Editar Cartões</translation>
    </message>
    <message>
        <source>Edit &amp;deck</source>
        <translation type="unfinished">&amp;Editar Cartões</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation type="unfinished">Ctrl+D</translation>
    </message>
    <message>
        <source>&amp;Import</source>
        <translation type="unfinished">&amp;Importar</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;Exportar</translation>
    </message>
    <message>
        <source>Show &amp;toolbar</source>
        <translation type="unfinished">Mostrar &amp;Barra de Ferramentas</translation>
    </message>
    <message>
        <source>Edit current card</source>
        <translation type="unfinished">Editar cartão atual</translation>
    </message>
    <message>
        <source>&amp;Edit current card</source>
        <translation type="unfinished">&amp;Editar cartão atual</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation type="unfinished">Ctrl+E</translation>
    </message>
    <message>
        <source>Delete current card</source>
        <translation type="unfinished">Apagar cartão atual</translation>
    </message>
    <message>
        <source>&amp;Delete current card</source>
        <translation type="unfinished">&amp;Apagar cartão atual</translation>
    </message>
    <message>
        <source>Del</source>
        <translation type="unfinished">Del</translation>
    </message>
    <message>
        <source>&amp;Clean duplicates</source>
        <translation type="unfinished">Apagar &amp;duplicatas</translation>
    </message>
    <message>
        <source>&amp;Configure Mnemosyne</source>
        <translation type="unfinished">&amp;Configurar Mnemosyne</translation>
    </message>
    <message>
        <source>Getting started</source>
        <translation type="unfinished">Iniciando</translation>
    </message>
    <message>
        <source>&amp;Getting started</source>
        <translation type="unfinished">&amp;Iniciando</translation>
    </message>
    <message>
        <source>Down, Down</source>
        <translation type="unfinished">Down, Down</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation type="unfinished">Enter</translation>
    </message>
    <message>
        <source>Return</source>
        <translation type="unfinished">Return</translation>
    </message>
    <message>
        <source>Space</source>
        <translation type="unfinished">Space</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation type="unfinished">Ctrl+R</translation>
    </message>
    <message>
        <source>Show statistics</source>
        <translation type="unfinished">Mostrar estatísticas</translation>
    </message>
    <message>
        <source>Show s&amp;tatistics</source>
        <translation type="unfinished">Mostrar &amp;estatísticas</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation type="unfinished">Ctrl+T</translation>
    </message>
    <message>
        <source>Tip of the day</source>
        <translation type="unfinished">Dica do dia</translation>
    </message>
    <message>
        <source>&amp;Tip of the day</source>
        <translation type="unfinished">&amp;Dica do dia</translation>
    </message>
    <message>
        <source>Main toolbar (Mnemosyne)</source>
        <translation type="unfinished">Barra de ferramentas principal (Mnemosyne)</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;Arquivo</translation>
    </message>
    <message>
        <source>&amp;Deck</source>
        <translation type="unfinished">&amp;Cartões</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation type="unfinished">Confi&amp;gurações</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished">A&amp;juda</translation>
    </message>
</context>
<context>
    <name>PreviewItemDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation type="unfinished">&lt;default&gt;</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation type="unfinished">Questão:</translation>
    </message>
</context>
<context>
    <name>PreviewItemFrm</name>
    <message>
        <source>Preview card</source>
        <translation type="unfinished">Pré visualizar cartão</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation type="unfinished">Questão:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation type="unfinished">Resposta:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="unfinished">Alt+O</translation>
    </message>
</context>
<context>
    <name>ProductTourFrm</name>
    <message>
        <source>Getting started</source>
        <translation type="unfinished">Iniciando</translation>
    </message>
    <message>
        <source>Greetings!

I am Mnemosyne, a type of butterfly named after the Greek goddess of Memory. 

I can make it more efficient for you to memorise and remember answers to questions, by helping you focus on the cards you&apos;re most likely to forget and by not wasting your time on things you know well.

For that, I&apos;ll decide when to ask you the questions, and you&apos;ll need to rate how well you remember the answers.

Let&apos;s look at the meaning of these ratings now.</source>
        <translation type="unfinished">Bem vindo!

Eu sou Mnemosyne, um tipo de borboleta conhecido como o deus grego da Memória. 

Posso lhe tornar mais fácil o processo de memorizar respostas à questões, lhe auxiliando a focar-se em cartões que você ainda não memorizou, e não o fazendo perder tempo com coisas que você já sabe bem.

Para isso, decidirei quando lhe fazer as questões, e você deverá avaliar o nível do quão bem você memorizou as respostas.

Vejamos o significado dos níveis.</translation>
    </message>
    <message>
        <source>Introduction</source>
        <translation type="unfinished">Introdução</translation>
    </message>
    <message>
        <source>Grades range from 0 to 5.

Grades 0 and 1 are used if you don&apos;t know the answer yet, or if you have forgotten it. A card with grade 1 is starting to get more familiar than one with grade 0, and will be repeated less often.

I will keep on asking you these questions until you give them a grade 2 or higher (the exact grade doesn&apos;t matter). Grade 2 basically means that you think you&apos;ll be able to remember the card for at least one or two days. It signals the transition between short and long term memory.

I will schedule this card at some future date, when I think you&apos;ll still be able to remember it with some effort, without having forgotten it completely. This is the most efficient for the learning process.</source>
        <translation type="unfinished">Níveis variam de 0 à 5.

Os níveis 0 e 1 são utilizados se você ainda não memorizou a resposta ainda, ou se você a esqueceu. Um cartão com nível 1 está se tornando mais familiar do que um de nível 0, e será repetido com menor freqüência.

Continuarei repetindo estas questões até que você a classifique como de nível 2 ou mais (o nível exato não importa). Nível 2 basicamente significa que você acha que conseguirá lembrar-se da resposta por pelo menos um ou dois dias. Ele demonstra a transição entre uma lembrança de curto e longo prazo.

Agendarei este cartão para uma data futura, quando eu achar que você ainda conseguirá lembrar-se dele com algum esforço, sem tê-lo esquecido completamente. Este é o método mais eficiente em um processo de aprendizagem.</translation>
    </message>
    <message>
        <source>Grades 0-2</source>
        <translation type="unfinished">Níveis 0-2</translation>
    </message>
    <message>
        <source>If in the future I ask you the question too soon, and you&apos;re able to remember it without any effort, you rate the card a 5. I&apos;ll take this into account by waiting a lot longer before asking you this question again.

If I get it just right, so that you remember it, albeit with some effort, you use grade 4.

If on the other hand it takes you significant effort to remember the answer, and you think I&apos;ve waited too long to ask you this question, then rate the card 3.

If you fail to remember it altogether, rate it either 0 or 1, and I&apos;ll keep on asking you this question until you think you&apos;ll be able to remember it again for a few days.</source>
        <translation type="unfinished">Se futuramente eu lhe perguntar uma questão cedo demais, e você conseguir lembrar-se da resposta sem nenhuma dificuldade, você deve classificar o cartão como de nível 5. Levarei isto em conta aguardando um período maior antes de lhe fazer a pergunta novamente.

Se eu acertar o período, de forma que você ainda consiga lembrar-se da resposta, mesmo que com alguma dificuldade, você deve classificá-la como de nível 4.

No entanto se você levar um bom tempo para lembrar-se da resposta, e você achar que eu demorei demais para repetir a perguntar, você deve classificá-la como de nível 3.

Se você não lembrar-se dela, classifique-a como de nível 0 ou 1, e continuarei repetindo a questão até que você consiga memorizá-la por alguns dias.</translation>
    </message>
    <message>
        <source>Grades 3-5</source>
        <translation type="unfinished">Níveis 3-5</translation>
    </message>
    <message>
        <source>If you&apos;re into statistics, I can keep detailed logs of your revisions.

Not only that, but if you want, I can upload transparently a completely anonymous version of these logs to a central site for analysis, so that you can help making me better. In this way, you also contribute to scientific research on long-term memory.

Uncheck the following box if you do not want to do this.</source>
        <translation type="unfinished">Se você gostar de estatísticas, posso manter registros detalhados de suas revisões.

Não somente isso, mas se você quiser, posso enviar transparentemente e anonimamente estes registros para uma central de análise, assim você pode ajudar em me tornar cada vez melhor. Desta forma você também contribui para uma pesquisa científica sobre memórias a longo prazo.

Desative a caixa abaixo se você não quiser fazer isto.</translation>
    </message>
    <message>
        <source>Upload anonymous logs</source>
        <translation type="unfinished">Enviar registros anônimos</translation>
    </message>
    <message>
        <source>(You can always change this setting later using the &apos;Configure Mnemosyne&apos; menu option.)</source>
        <translation type="unfinished">(Você pode alterar esta opção depois utilizando o menu de Configuração do Mnemosyne.)</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation type="unfinished">Estatísticas</translation>
    </message>
    <message>
        <source>Now you&apos;re ready to start!
&lt;p&gt;
Add new cards by clicking on the icon with the &apos;plus&apos; sign in the top left.
&lt;p&gt;
Remember, there is no need to worry about saving your work, I will do so automatically.
&lt;p&gt;
For best results, I suggest you do your revisions every day, although I&apos;ll try to cope as best I can if you postpone your revisions or if you want to learn ahead of time.
&lt;p&gt;
For more documentation, see http://www.mnemosyne-proj.sourceforge.net.
&lt;p&gt;
Happy learning!</source>
        <translation type="unfinished">Agora você está pronto para começar!
&lt;p&gt;
Adicione novos cartões clicando no ícone com o sinal de &apos;mais&apos; no canto superior esquerdo.
&lt;p&gt;
Lembre-se, você não precisa se preocupar em salvar seus trabalhos, farei isto automaticamente.
&lt;p&gt;
Para melhores resultados, sugiro você fazer suas revisões todos os dias, apesar de que tentarei lidar da melhor forma possível caso você adie suas revisões ou se quiser aprender mais durante um período.
&lt;p&gt;
Para maiores informações, visite http://www.mnemosyne-proj.sourceforge.net.
&lt;p&gt;
Boa aprendizagem!</translation>
    </message>
    <message>
        <source>Ready to start</source>
        <translation type="unfinished">Pronto para começar</translation>
    </message>
</context>
<context>
    <name>QTextEdit2</name>
    <message>
        <source>Insert &amp;image</source>
        <translation type="unfinished">Inserir &amp;imagem</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation type="unfinished">Ctrl+I</translation>
    </message>
    <message>
        <source>Insert &amp;sound</source>
        <translation type="unfinished">Inserir &amp;som</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation type="unfinished">Ctrl+S</translation>
    </message>
    <message>
        <source>&amp;3-sided input</source>
        <translation type="unfinished">Resposta com &amp;3 partes</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation type="unfinished">Arquivos de imagem</translation>
    </message>
    <message>
        <source>Insert image</source>
        <translation type="unfinished">Inserir imagem</translation>
    </message>
    <message>
        <source>Sound files</source>
        <translation type="unfinished">Arquivos de som</translation>
    </message>
    <message>
        <source>Insert sound</source>
        <translation type="unfinished">Inserir som</translation>
    </message>
</context>
<context>
    <name>StatisticsDlg</name>
    <message>
        <source>Scheduled cards for the next days:

</source>
        <translation type="obsolete">Cartões agendados para os próximos dias:

</translation>
    </message>
    <message>
        <source>In</source>
        <translation type="unfinished">Em</translation>
    </message>
    <message>
        <source>day(s) :</source>
        <translation type="unfinished">dia(s) :</translation>
    </message>
    <message>
        <source>Number of cards with the following grades:

</source>
        <translation type="unfinished">Número de cartões nos seguintes níveis:

</translation>
    </message>
    <message>
        <source>Grade</source>
        <translation type="unfinished">Nível</translation>
    </message>
    <message>
        <source>No current card.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grade:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Easiness:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Repetitions:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lapses:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Days since last repetition:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Days until next repetition:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scheduled cards for next week:

</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StatisticsFrm</name>
    <message>
        <source>Category</source>
        <translation type="unfinished">Categoria</translation>
    </message>
    <message>
        <source>Cards</source>
        <translation type="unfinished">Cartões</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation type="unfinished">Estatísticas</translation>
    </message>
    <message>
        <source>Schedule</source>
        <translation type="unfinished">Agenda</translation>
    </message>
    <message>
        <source>Grades</source>
        <translation type="unfinished">Níveis</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation type="unfinished">Categorias</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>Current card</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TipDlg</name>
    <message>
        <source>For optimal results, it&apos;s best to do your repetitions every day.</source>
        <translation type="unfinished">Para melhores resultados, faça as repetições todos os dias.</translation>
    </message>
    <message>
        <source>If you&apos;ve been away for a few days, don&apos;t worry about your backlog. Do as many cards as you feel like to catch up, the rest will be automatically rescheduled to the future.</source>
        <translation type="unfinished">Se você deixar de fazer por alguns dias, não se preocupe sobre seu atraso. Faça quantos cartões conseguir, os outros serão automaticamente reagendados para uma data futura.</translation>
    </message>
    <message>
        <source>The &apos;number of grade 0 cards to learn at once&apos; setting determines how many new cards you are trying to learn at the same time. It does &lt;b&gt;not&lt;/b&gt; tell you how many new cards you need to learn per day. You are the judge of that: you can learn more cards or less cards, depending on how you feel.</source>
        <translation type="unfinished">A opção &apos;número de cartões de nível 0 para aprender simultaneamente&apos; determina quantos novos cartões você irá tentar aprender simultaneamente. Ela &lt;b&gt;não&lt;/b&gt; determina quantos novos cartões você precisa aprender por dia. Você é quem diz isso: você pode aprender mais ou menos cartões, dependendo de como estiver se sentindo.</translation>
    </message>
    <message>
        <source>In summary, try to do your repetitions every day, but don&apos;t worry too much about getting the &apos;scheduled&apos; counter to zero, and certainly not about getting the &apos;Not memorised&apos; counter to zero.</source>
        <translation type="unfinished">Resumindo, tente fazer as repetições todos os dias, mas não se preocupe muito em deixar o contador de itens agendados em zero, e nem o contador de itens já memorizados.</translation>
    </message>
    <message>
        <source>Grade 1 cards are different from grade 0 cards in the sense that they show up less often and are not subject to the &apos;number of grade 0 cards to learn at once&apos; setting.</source>
        <translation type="unfinished">Cartões de nível 1 se diferencial de cartões de nível 0 pelo fato de que eles aparecem com menor freqüência e não são sujeitos a opção &apos;número de cartões de nível 0 para aprender simultaneamente&apos;.</translation>
    </message>
    <message>
        <source>You can use keyboard shortcuts to do your repetitions. Enter, Return or Space stand for the default action (&apos;Show answer&apos; or &apos;grade 4&apos;). The number keys can be used for grading.</source>
        <translation type="unfinished">Você pode utilizar atalhos de teclado para fazer suas repetições. Enter, Return e a Barra de Espaço ativam a ação padrão (&apos;Mostrar resposta&apos; ou &apos;nível 4&apos;). As teclas numéricas podem ser utilizadas para fazer a classificação das respostas.</translation>
    </message>
    <message>
        <source>You can select the categories you wish to study in the &apos;Activate categories&apos; menu option.</source>
        <translation type="unfinished">Você pode escolher as categorias que deseja estudar na opção do menu &apos;Ativar Categorias&apos;.</translation>
    </message>
    <message>
        <source>It is recommended to put all your cards in a single database and use categories to organise them. Using &apos;Activate categories&apos; is much more convenient than have to load and unload several databases.</source>
        <translation type="unfinished">É recomendável colocar todos os seus cartões em uma mesma base de dados e utilizar categorias para organizá-los. Utilizar a opção &apos;Ativar categorias&apos; é muito mais conveniente do que ter que abrir diversas bases de dados.</translation>
    </message>
    <message>
        <source>You can import cards in a wide variety of formats: tab delimited txt files, Supermemo files, ... .</source>
        <translation type="unfinished">Você pode importar cartões em vários formatos: arquivos de texto delimitados por tabulações, arquivos do Supermemo, ... .</translation>
    </message>
    <message>
        <source>If you have cards in Word or Excel, export them to tab delimited txt files with UTF-8 unicode encoding to be able to import them into Mnemosyne.</source>
        <translation type="unfinished">Se você tiver cartões no Word ou Excel Word or Excel, exporte-os para arquivos de texto delimitados por tabulações com codificação UTF-8 para importá-los para o Mnemosyne.</translation>
    </message>
    <message>
        <source>If you want to print out your cards, export them to a txt file which you can then print from your favourite Word processor.</source>
        <translation type="unfinished">Se quiser imprimir seus cartões, exporte-os para um arquivo de texto e você pode imprimí-los utilizando seu editor de textos favorito.</translation>
    </message>
    <message>
        <source>You can share your cards with someone else by exporting them to XML and choosing the &apos;Reset learning data&apos; option on export.</source>
        <translation type="unfinished">Você pode compartilhar seus cartões com outras pessoas exportando-os para um arquivo XML e escolhendo a opção &apos;Reiniciar dados de aprendizagem&apos; ao exportar.</translation>
    </message>
    <message>
        <source>If you study a foreign language with a different script, the default font size is sometimes a bit small. If you want to increase the size of these characters but keep the size of English text, use the &apos;increase size of non-latin characters by X points&apos; option.</source>
        <translation type="unfinished">Se você estiver estudando uma língua estrangeira que utilize caracteres diferentes, o tamanho padrão das fontes pode ser pequeno demais. Se você quiser aumentar o tamanho destes caracteres mas manter o tamanho normal das fontes atuais, utilize a opção &apos;Aumentar tamanho dos caracteres não latinos em X pontos&apos;.</translation>
    </message>
    <message>
        <source>You can add images and sounds to your cards. Right-click on the question or answer field when editing a card to bring up a pop-up menu to do so.</source>
        <translation type="unfinished">Você pode inserir imagens e sons a seus cartões. Clique com o botão direito na questão ou resposta enquanto estiver editando-a para mostrar o menu com as opções.</translation>
    </message>
    <message>
        <source>It is recommended to keep your sound and image files inside your .mnemosyne directory. That way, it&apos;s easier to transfer your data between different computers.</source>
        <translation type="unfinished">É recomendado manter seus arquivos de som e imagem dentro de seu diretório do.mnemosyne. Desta forma, será mais simples transferir dados entre diferentes computadores.</translation>
    </message>
    <message>
        <source>When adding a three-sided card, two regular cards will be created. One with as question the written form and as answer the pronunciation and the translation, and one with as question the translation and as answer the written form and the pronunciation.</source>
        <translation type="unfinished">Quando estiver adicionando um cartão de 3 partes, dois cartões normais serão criados. Um tendo como questão a forma escrita e a resposta com a forma de pronúncia e a tradução, e outro tendo como questão a tradução e como resposta a forma escrita e a forma de pronúncia.</translation>
    </message>
    <message>
        <source>You can use basic HTML tags in your cards to control their appearance.</source>
        <translation type="unfinished">Você pode utilizar tags HTML básicas em seus cartões para formatar sua aparência.</translation>
    </message>
    <message>
        <source>Mnemosyne can use LaTeX to render mathematical formulas, e.g. &lt;$&gt;x^2+y^2=z^2&lt;/$&gt;. (For this, you need LaTeX and dvipng installed.)</source>
        <translation type="unfinished">Mnemosyne pode utilizar o LaTeX para renderizar fórmular matemáticas, por exemplo &lt;$&gt;x^2+y^2=z^2&lt;/$&gt;. (Para isto, você precisa ter o LaTeX e o dvipng instalados.)</translation>
    </message>
    <message>
        <source>The best way to backup your data is to copy your .mnemosyne directory (if you follow the recommended procedure to keep all your files there) and move it to a different drive. Mnemosyne keeps automatic XML-based backups in .mnemosyne/backups, but that won&apos;t help you if that drive dies... </source>
        <translation type="unfinished">A melhor forma de fazer uma cópia de segurança de seus dados é copiar o seu diretório .mnemosyne (se você seguir a recomendação de manter todos os seus arquivos neste diretório) e copiá-lo para um dispositivo diferente. O Mnemosyne mantém uma cópia automática em forma de XML no diretório .mnemosyne/backups, mas isto não te ajudará caso você perca os seus dados... </translation>
    </message>
    <message>
        <source>You can run Mnemosyne from a USB key. Copy C:\Program Files\Mnemosyne to your USB key, and then copy the .mnemosyne directory from your home directory to inside the Mnemosyne directory on the USB key.</source>
        <translation type="unfinished">Você pode executar o Mnemosyne à partir de um dispositivo USB. Copie C:\Arquivos de Programas\Mnemosyne para seu dispositivo USB, e então copie o diretório .mnemosyne da sua pasta pessoal para dentro do diretório do Mnemosyne no dispositivo USB.</translation>
    </message>
    <message>
        <source>If you use Mnemosyne on multiple computers, there is a handy tool called Unison to help you synchronise your data. See the Mnemosyne website for more information.</source>
        <translation type="unfinished">Se você utiliza o Mnemosyne em múltiplos computadores, existe uma ferramente que pode lhe auxiliar chamada Unison, que mantém seus dados sincronizados. Você pode obter mais informações no website do Mnemosyne.</translation>
    </message>
    <message>
        <source>You can sort the cards in the &apos;Edit Deck&apos; dialog by answer or by category by clicking on the corresponding column title. Clicking again changes the sort order.</source>
        <translation type="unfinished">Você pode organizar seus cartões na janela &apos;Editar Cartões&apos; por resposta ou categoria clicando no título da coluna correspondente. Clicando novamente altera a ordem de organização.</translation>
    </message>
    <message>
        <source>If you want more fine-grained control over LaTeX&apos;s behaviour, see the explanation of the &lt;$$&gt;...&lt;/$$&gt; and &lt;latex&gt;...&lt;/latex&gt; tags on Mnemosyne&apos;s website.</source>
        <translation type="unfinished">Se você quiser mais controle sobre o comportamento do LaTeX, verifique uma explicação sobre as tags &lt;$$&gt;...&lt;/$$&gt; e &lt;latex&gt;...&lt;/latex&gt; no website do Mnemosyne.</translation>
    </message>
    <message>
        <source>Advanced users can customise more of Mnemosyne by editing the config.py file in their .mnemosyne directory. They can also install plugins to customise Mnemosyne even further.</source>
        <translation type="unfinished">Usuários avançados pode customizar o Mnemosyne editando o arquivo config.py no diretório .mnemosyne. També é possível instalar plugins ara customizar ainda mais o Mnemosyne.</translation>
    </message>
</context>
<context>
    <name>TipFrm</name>
    <message>
        <source>Tip of the day</source>
        <translation type="unfinished">Dica do dia</translation>
    </message>
    <message>
        <source>&lt;b&gt;Did you know...?&lt;/b&gt;</source>
        <translation type="unfinished">&lt;b&gt;Você sabia...?&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&amp;Show tips on startup</source>
        <translation type="unfinished">&amp;Mostrar dicas ao iniciar</translation>
    </message>
    <message>
        <source>Alt+S</source>
        <translation type="unfinished">Alt+S</translation>
    </message>
    <message>
        <source>&amp;Previous</source>
        <translation type="unfinished">&amp;Anterior</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation type="unfinished">Alt+P</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation type="unfinished">&amp;Próxima</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation type="unfinished">Alt+N</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Fechar</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation type="unfinished">Alt+C</translation>
    </message>
</context>
</TS>
